@@ -48,12 +48,12 @@ class Sum(Remote):
 
 
 class TestEmit(unittest.TestCase):
-    async def asyncSetUp(self) -> None:
+    def setUp(self) -> None:
         self.echo_times = 0
         self.dsn = "redis://localhost"
 
-    async def asyncTearDown(self) -> None:
-        await e.stop()
+    def tearDown(self) -> None:
+        asyncio.run(e.stop())
 
     @async_test
     async def test_async_register(self):
@@ -115,7 +115,7 @@ class TestEmit(unittest.TestCase):
 
     @async_test
     async def test_heart_beat(self):
-        e.register("hi", self.on_echo)
+        await e.async_register("hi", self.on_echo)
         await e.start(e.Engine.REDIS, heart_beat=0.5, dsn=self.dsn, start_server=True)
         await asyncio.sleep(1)
 
